@@ -3,12 +3,10 @@ import logging
 import re
 from enum import Enum
 
+import db_hammer.entity_util as entity_util
 from db_hammer import DB_TYPE_MYSQL
-from db_hammer.csv import start as csv_start
-from db_hammer.entity_util import update_sql, insert_sql, delete_sql, entity_list, where_entity, where_like_entity, \
-    order_by_pagination, get_entity_primary_key
 from db_hammer.page import PageOutput, PageInput
-from db_hammer.sql_exception import SqlException, FetchRowsException, ExistException
+from db_hammer.sql_exception import SqlException, FetchRowsException, NoExistException
 from db_hammer.util.date import date_to_str
 
 
@@ -18,18 +16,27 @@ class DataType(Enum):
 
 
 class BaseConnection(object):
-    def __init__(self, **kwargs):
+    def __init__(self,
+                 debug=False,
+                 db_type=DB_TYPE_MYSQL,
+                 log=logging.getLogger(__name__),
+                 caps=None,
+                 **kwargs):
         """
         :param kwargs:
         """
-        self.log = kwargs.get("log", logging.getLogger(__name__))
-        self.Db_NAME = kwargs.get("db_name")
-        self.caps = kwargs.get("caps", None)  # A:大写 a:小写
-        self.conn = None  # type:Connect
-        self.cursor = None  # type:cursor
+        self.database = None
+        self.db_type = db_type
+        self.debug = debug
+        self.log = log
+        self.caps = caps  # A:大写 a:小写
+        self.conn = None
+        self.cursor = None
         self.table_column_cache = {}
-        if self.db_type is None:
-            self.db_type = DB_TYPE_MYSQL
+        if self.debug:
+            logging.basicConfig(level=logging.DEBUG,
+                                format='%(asctime)s %(filename)s:%(lineno)d %(levelname)s | %(message)s',
+                                datefmt='%Y-%m-%d %H:%M:%S')
 
     def __enter__(self):
         return self
@@ -62,7 +69,7 @@ class BaseConnection(object):
     def sql_params(self, sql: str, params: dict):
         if params is None:
             return sql, None
-        ps = re.findall('(?<!\w):\w+', sql)
+        ps = re.findall(r'(?<!\w):\w+', sql)
         start = 0
         new_params = {}
         for p in ps:
@@ -131,10 +138,10 @@ class BaseConnection(object):
         col_names = self.cursor.description
         return self._data_to_map(col_names, data)
 
-    def select_value(self, sql: str, params=None) -> str:
+    def select_value(self, sql: str, params=None):
         """
         获取第一列第一行的值
-        :param sql:
+        :params sql:
         :return:
         """
         self.log.debug("执行SQL:" + sql)
@@ -175,7 +182,7 @@ class BaseConnection(object):
         col_names = self.cursor.description
         return self._data_to_map(col_names, data)
 
-    def select_dict(self, sql: str, params=None) -> dict:
+    def select_dict(self, sql: str, params=None) -> dict or None:
         """
         获取字典数据，以字典方式返回: dict
         :param params:
@@ -265,7 +272,7 @@ class BaseConnection(object):
         获取数据列的SQL
         占位参数：
             ${TABLE_NAME} : 表名
-            ${DB_NAME} : 连接的数据库名
+            ${database} : 连接的数据库名
 
         :return:
             COLUMN_NAME : 名称
@@ -283,7 +290,7 @@ class BaseConnection(object):
             NUMERIC_PRECISION AS DATA_PRECISION
              FROM INFORMATION_SCHEMA.COLUMNS T
              WHERE 
-             TABLE_NAME = '{table_name}' AND TABLE_SCHEMA = '{self.Db_NAME}'
+             TABLE_NAME = '{table_name}' AND TABLE_SCHEMA = '{self.database}'
             """
 
     def gen_insert_dict_sql(self, dict_data: dict, table_name: str):
@@ -302,7 +309,7 @@ class BaseConnection(object):
                 values[column_name] = self.__get_column_value(data_type=data_type, value=dict_data[column_name])
         else:
             return None
-        sql = f"""INSERT INTO {self.Db_NAME}.{table_name} ({','.join(values.keys())}) VALUES ({','.join(values.values())})"""
+        sql = f"""INSERT INTO {self.database}.{table_name} ({','.join(values.keys())}) VALUES ({','.join(values.values())})"""
         return sql
 
     def __get_column(self, name, columns):
@@ -321,14 +328,17 @@ class BaseConnection(object):
             self.table_column_cache[table_name] = columns
             return columns
 
-    def gen_update_dict_sql(self, dict_data: dict, table_name: str, where: str, not_update_colunms=[]):
+    def gen_update_dict_sql(self, dict_data: dict, table_name: str, where: str, not_update_colunms=None):
         """
         根据字典生成Update语句
+        :not_update_colunms: 不更新列
         :param dict_data:  列新字典
         :param table_name: 表名
         :param where: 带上where条件
         :return:
         """
+        if not_update_colunms is None:
+            not_update_colunms = []
         columns = self.__select_db_columns(table_name=table_name)
         values = {}
         if dict_data is not None:
@@ -344,7 +354,7 @@ class BaseConnection(object):
         for c in values.keys():
             if c not in not_update_colunms:
                 sets.append(f"{c}={values[c]}")
-        update_sql = f"UPDATE {self.Db_NAME}.{table_name} SET {','.join(sets)} " + where
+        update_sql = f"UPDATE {self.database}.{table_name} SET {','.join(sets)} " + where
         return update_sql
 
     def __get_column_value(self, data_type, value):
@@ -376,93 +386,84 @@ class BaseConnection(object):
     def convert_str(self, s: str):
         return str(s)
 
-    def export_data_file(self, sql, dir_path, file_mode="txt", pack_size=500000, bachSize=10000, add_header=True,
-                         data_split_chars=',',
-                         data_close_chars='"', encoding="utf-8", outingCallback=None):
-        """导出数据文件
-        @:param sql 导出时的查询SQL
-        @:param dir_path 导出的数据文件存放目录
-        @:param file_mode 导出文件格式：txt|gz|csv
-        @:param add_header 数据文件是否增加表头
-        @:param pack_size  每个数据文件大小，默认为50万行，强烈建议分割数据文件，单文件写入速度会越来越慢
-        @:param bachSize   游标大小
-        @:param data_split_chars 每条数据字段分隔字符,csv文件默认为英文逗号
-        @:param data_close_chars 每条数据字段关闭字符,csv文件默认为英文双引号
-        @:param encoding 文件编码格式，默认为utf-8
-        @:param outingCallback 导出过程中的回调方法
-        """
-        csv_start(cursor=self.cursor,
-                  sql=sql,
-                  path=dir_path,
-                  bachSize=bachSize,
-                  PACK_SIZE=pack_size,
-                  file_mode=file_mode,
-                  add_header=add_header,
-                  CSV_SPLIT=data_split_chars,
-                  CSV_FIELD_CLOSE=data_close_chars,
-                  encoding=encoding,
-                  callback=outingCallback,
-                  log=self.log)
+    def save_entity(self, entity, commit=True, pass_null=False):
+        """根据主键判断是否存在，决定插入或更新"""
+        entity_util.init_entity(entity=entity)
+        try:
+            self.update_entity(entity=entity, commit=commit, check_exist=True, pass_null=pass_null)
+        except NoExistException:
+            self.insert_entity(entity=entity, commit=commit)
 
     def insert_entity(self, entity, commit=True):
         """传入实体保存到数据库"""
-        sql, values = insert_sql(entity=entity)
-        sql, values = self.sql_params(sql, values)
+        entity_util.init_entity(entity=entity)
+        sql, values = entity_util.insert_sql(entity=entity)
         i = self.execute(sql, values)
         primary_key = self.cursor.lastrowid
         if primary_key != 0:
-            setattr(entity, get_entity_primary_key(entity)[0], primary_key)
+            setattr(entity, entity_util.get_entity_primary_key(entity)[0], primary_key)
         if i != 1:
             raise FetchRowsException(f"影响条数为{i}")
         if commit:
             self.commit()
         return entity
 
-    def update_entity(self, entity, pass_null=False, commit=True, check_exist=False) -> None:
+    def update_entity(self, entity, pass_null=False, commit=True, check_exist=False) -> int:
+        entity_util.init_entity(entity=entity)
         if check_exist:
             es = self.select_entity_by_pk(entity=entity)
             if es is None:
-                raise ExistException(f"找不到要更新的实体")
-        sql, values = update_sql(entity=entity, pass_null=pass_null)
+                raise NoExistException(f"找不到要更新的实体")
+        sql, values = entity_util.update_sql(entity=entity, pass_null=pass_null)
         self.log.debug(f"SQL:{sql}")
         self.log.debug(f"params:{values}")
-        sql, values = self.sql_params(sql, values)
-        i = self.execute(sql, values)
-        if commit:
-            self.commit()
-
-    def delete_entity(self, entity, commit=True) -> int:
-        sql, values = delete_sql(entity=entity)
-        self.log.debug(sql)
-        self.log.debug(f"params:{values}")
-        sql, values = self.sql_params(sql, values)
         i = self.execute(sql, values)
         if commit:
             self.commit()
         return i
 
-    def select_entity_list(self, cls=None, sql=None, params=None, like_entity=None, entity=None, rel="AND",
+    def delete_entity(self, entity, commit=True) -> int:
+        entity_util.init_entity(entity=entity)
+        sql, values = entity_util.delete_sql(entity=entity)
+        self.log.debug(sql)
+        self.log.debug(f"params:{values}")
+        i = self.execute(sql, values)
+        if commit:
+            self.commit()
+        return i
+
+    def select_entity_list(self,
+                           entity_class=None,
+                           sql=None,
+                           params=None,
+                           contain_entity=None,  # 生成like字段条件
+                           eq_entity=None,  # 生成等的字段条件
+                           where_rel="AND",
                            page: PageInput = None):
+        if contain_entity:
+            entity_util.init_entity(entity=contain_entity)
+        elif eq_entity:
+            entity_util.init_entity(entity=eq_entity)
         if sql is None:
-            if like_entity is not None:
-                if cls is None:
-                    cls = like_entity.__class__
-                table_name = getattr(like_entity, "__table_name__")
-            elif entity is not None:
-                if cls is None:
-                    cls = entity.__class__
-                table_name = getattr(entity, "__table_name__")
+            if contain_entity is not None:
+                if entity_class is None:
+                    entity_class = contain_entity.__class__
+                table_name = getattr(contain_entity, "__table_name__")
+            elif eq_entity is not None:
+                if entity_class is None:
+                    entity_class = eq_entity.__class__
+                table_name = getattr(eq_entity, "__table_name__")
             else:
-                table_name = getattr(cls, "__table_name__")
+                table_name = getattr(entity_class, "__table_name__")
 
             sql = "SELECT * FROM " + table_name
         if params is None:
-            if like_entity is not None:
-                where, values = where_like_entity(entity=like_entity, rel=rel)
+            if contain_entity is not None:
+                where, values = entity_util.where_like_entity(entity=contain_entity, rel=where_rel)
                 sql += where
                 params = values
-            elif entity is not None:
-                where, values = where_entity(entity=entity, rel=rel)
+            elif eq_entity is not None:
+                where, values = entity_util.where_entity(entity=eq_entity, rel=where_rel)
                 sql += where
                 params = values
         if sql is None:
@@ -470,11 +471,11 @@ class BaseConnection(object):
         if page is not None:
             pages, rowsNumber = self.select_page_size(sql=sql, params=params,
                                                       page_size=page.page_size)
-            order_by = order_by_pagination(entity=cls, pagination=page)
+            order_by = entity_util.order_by_pagination(entity=entity_class, pagination=page)
             dict_list = self.select_dict_page_list(sql=f"{sql} {order_by}", params=params,
                                                    page_size=page.page_size,
                                                    page_start=page.page_start)
-            values = entity_list(dict_list=dict_list, cls=cls)
+            values = entity_util.entity_list(dict_list=dict_list, entity_class=entity_class)
             pageOut = PageOutput()
             pageOut.rows = values
             pageOut.page_start = page.page_start
@@ -486,16 +487,18 @@ class BaseConnection(object):
             return pageOut
         else:
             dict_list = self.select_dict_list(sql=sql, params=params)
-            values = entity_list(dict_list=dict_list, cls=cls)
+            values = entity_util.entity_list(dict_list=dict_list, entity_class=entity_class)
             return values
 
-    def select_entity_first(self, cls=None, sql=None, params=None, like_entity=None, entity=None):
-        ll = self.select_entity_list(cls, sql=sql, params=params, like_entity=like_entity, entity=entity)
+    def select_entity_first(self, entity_class=None, sql=None, params=None, contain_entity=None, eq_entity=None):
+        ll = self.select_entity_list(entity_class, sql=sql, params=params, contain_entity=contain_entity,
+                                     eq_entity=eq_entity)
         if ll is not None and len(ll) > 0:
             return ll[0]
 
     def select_entity_by_pk(self, entity, pk_value=None):
-        primary_key, _pk_value = get_entity_primary_key(entity)
+        entity_util.init_entity(entity=entity)
+        primary_key, _pk_value = entity_util.get_entity_primary_key(entity)
         table_name = getattr(entity, "__table_name__")
         _SQL = ""
         if isinstance(primary_key, list):
@@ -509,7 +512,7 @@ class BaseConnection(object):
             pk_value = _pk_value
 
         params = {}
-        if isinstance(pk_value, str):
+        if isinstance(pk_value, (str, int)):
             params[primary_key] = pk_value
         else:
             params = pk_value
