@@ -1,5 +1,6 @@
 import os
 import re
+import zipfile
 
 
 def get_dir_files(path: str, mode='F', absolute=False, filter_re=""):
@@ -36,10 +37,10 @@ def get_dir_files(path: str, mode='F', absolute=False, filter_re=""):
                     aa.append(root)
             if mode == "FD" and re.match(filter_re, root) is not None:
                 aa.append(root)
-        return list(set(aa))
+        return aa
     if mode == "AF" or mode == "AD" or mode == "AFD":
         for root, dirs, files in os.walk(top=path, topdown=True):
-            if mode in ("AF", "AFD"):
+            if mode == "AF":
                 if absolute:
                     ff = []
                     for f in files:
@@ -47,14 +48,24 @@ def get_dir_files(path: str, mode='F', absolute=False, filter_re=""):
                             ff.append(os.path.join(root, f))
                     files = ff
                 aa += files
-            if mode in ("AD", "AFD"):
+            if mode == "AD":
                 if os.path.isdir(root):
                     if re.match(filter_re, root) is not None:
                         aa.append(root)
             if mode == "AFD":
                 if re.match(filter_re, root) is not None:
                     aa.append(root)
-        return list(set(aa))
+        return aa
+
+
+def zip_dir(dir_path, out):
+    z = zipfile.ZipFile(out, 'w', zipfile.ZIP_DEFLATED)
+    for path, dirs, filenames in os.walk(dir_path):
+        this_path = os.path.abspath(dir_path)
+        fpath = path.replace(this_path, '')
+        for filename in filenames:
+            z.write(os.path.join(path, filename), os.path.join(fpath, filename))
+    z.close()
 
 
 if __name__ == '__main__':
